<template>
  <a-spin :spinning='load'>
    <a-card :bordered='false'>
      <!-- 查询区域 -->
      <div class='table-page-search-wrapper'>
        <a-form layout='inline' @keyup.enter.native='searchQuery'>
          <a-row :gutter='24'>
            <a-col :md='6' :sm='8'>
              <a-form-item label='参数名称'>
                <a-input v-model='queryParam.parameterName' placeholder='请输入参数名称'></a-input>
              </a-form-item>
            </a-col>
            <a-col :md='6' :sm='8'>
              <a-form-item label='参数编号'>
                <a-input v-model='queryParam.parameterCode' placeholder='请输入参数编号'></a-input>
              </a-form-item>
            </a-col>
            <a-col :md='6' :sm='8'>
            <span class='table-page-search-submitButtons' style='float: left;overflow: hidden;'>
              <a-button icon='search' type='primary' @click='searchQuery'>查询</a-button>
              <a-button icon='reload' style='margin-left: 8px' type='primary' @click='searchReset'>重置</a-button>
              <a-button icon='plus' style='margin-left: 8px' type='primary' @click='emptyHandleAdd'>新增参数</a-button>
              <a-button icon='plus' style='margin-left: 8px' type='primary' @click='handleAdd'>自定义参数</a-button>
            </span>
            </a-col>
          </a-row>
        </a-form>
      </div>
      <div>
        <a-table
          ref='table'
          :columns='columns'
          :customRow='clickThenSelect'
          :dataSource='dataSource'
          :loading='loading'
          :pagination='ipagination'
          :rowSelection="{selectedRowKeys: selectedRowKeys, onChange: onSelectChange, type:'radio'}"
          bordered
          class='j-table-force-nowrap'
          rowKey='id'
          size='small'
          @change='handleTableChange'
        >
          <!--状态栏个性展示-->
          <span slot='action' slot-scope='text, record'>
             <span v-if='record.type == 0'>
            <a @click='script(record)'>脚本</a>
                <a-divider type='vertical' />
          </span>
          <a href='javascript:' @click='handleEdit(record)'>编辑</a>
          <a-divider type='vertical' />
           <a-popconfirm title='确定删除吗?' @confirm='() => handleDelete(record.id)'>
                  <a>删除</a>
           </a-popconfirm>
        </span>
        </a-table>
      </div>
      <!-- table区域-end -->

      <!-- 表单区域 -->
      <!--      <empty-parameter-model ref='emptyModalForm' @ok='modalFormOk' :server-id='serverId' />-->
      <parameter-address ref='modalAddress' :server-id='serverId' @ok='modalFormOk' />
      <customize-parameter-model ref='modalForm' :server-id='serverId' @ok='modalFormOk' />
      <script-model ref='scriptForm' />
    </a-card>
  </a-spin>
</template>

<script>
import ScriptModel from './script/ScriptModel'
import EmptyParameterModel from './EmptyParameterModel'
import ParameterAddress from './select/ParameterAddress'
import CustomizeParameterModel from './CustomizeParameterModel'
import { JeecgListMixin } from '@/mixins/JeecgListMixin'
import JDictSelectTag from '@/components/dict/JDictSelectTag'
import JInput from '@/components/jeecg/JInput'
import JEllipsis from '@/components/jeecg/JEllipsis'
import { getAction } from '@/api/manage'

export default {
  name: 'EmptyParameter',
  mixins: [JeecgListMixin],
  components: {
    ParameterAddress,
    CustomizeParameterModel,
    EmptyParameterModel,
    JDictSelectTag,
    JInput,
    JEllipsis,
    ScriptModel
  },
  data() {
    return {
      /* 排序参数 */
      isorter:{
        column: 'parameterCode',
        order: 'desc',
      },
      columns: [
        {
          title: '参数编号',
          align: 'center',
          dataIndex: 'parameterCode'
        },
        {
          title: '参数名称',
          align: 'center',
          dataIndex: 'parameterName'
        },
        {
          title: '描述',
          align: 'center',
          dataIndex: 'parameterDescribe'
        },
        // {
        //   title: '数据来源',
        //   align: 'center',
        //   dataIndex: 'parameterDescribe'
        // },
        {
          title: '参数类型',
          align: 'center',
          dataIndex: 'parameterType'
        },
        {
          title: '类型',
          align: 'center',
          dataIndex: 'type',
          customRender: function(t, r, index) {
            if (t == 0) {
              return '自定义参数'
            } else if (t == 1) {
              return '参数'
            }
            return ''
          }
        },
        {
          title: '地址',
          align: 'center',
          dataIndex: 'address'
        },
        {
          title: '读写类型',
          align: 'center',
          dataIndex: 'readWriteType'
        },
        {
          title: '操作',
          dataIndex: 'action',
          align: 'center',
          scopedSlots: { customRender: 'action' }
        }
      ],
      load: false,
      url: {
        list: '/empty/parameter/list',
        delete: '/empty/parameter/delete'
      }
    }
  },
  props: ['serverId', 'tree'],
  watch: {
    serverId: {
      handler() {
        this.loadData()
      }
    }
  },
  methods: {
    // 查询终端列表
    loadData(arg) {
      //加载数据 若传入参数1则加载第一页的内容
      if (arg === 1) {
        this.ipagination.current = 1
      }
      this.onClearSelected()
      var params = this.getQueryParams()//查询条件
      params.equipmentId = this.serverId
      this.loading = true
      getAction(this.url.list, params).then((res) => {
        if (res.success) {
          this.dataSource = res.result.records
          this.ipagination.total = res.result.total
          if (res.result.records.length > 0) {
            this.selectedRowKeys[0] = this.dataSource[0].id
          }
        }
        if (res.code === 510) {
          this.$message.warning(res.message)
        }
        this.loading = false
      })

    },
    clickThenSelect(record) {
      return {
        on: {
          click: () => {
            this.onSelectChange(record.id.split(','), [record])
          }
        }
      }
    },
    onSelectChange(selectedRowKeys) {
      this.selectedRowKeys = selectedRowKeys
    },
    modalFormOk(val) {
      // 调用父组件方法
      this.$emit('tree')
      // 新增/修改 成功时，重载列表
      this.loadData()
      this.selectedRowKeys = [val.id]
    },
    searchQuery() {
      this.loadData()
      this.onClearSelected()
    },
    searchReset() {
      this.queryParam = {}
      this.loadData()
      this.onClearSelected()
    },
    handleEdit(record) {
      this.$refs.modalForm.edit(record)
      this.$refs.modalForm.title = '编辑'
      this.$refs.modalForm.disableSubmit = false
    },
    script(record) {
      this.$refs.scriptForm.edit(record)
      this.$refs.scriptForm.disableSubmit = false
    },
    emptyHandleEdit(record) {
      this.$refs.emptyModalForm.edit(record)
      this.$refs.emptyModalForm.title = '编辑'
      this.$refs.emptyModalForm.disableSubmit = false
    },
    emptyHandleAdd() {
      this.$refs.modalAddress.add()
      this.$refs.modalAddress.visible1 = true
      // this.$refs.modalAddress.loadData()
    },
    handleAdd() {
      this.$refs.modalForm.add()
      this.$refs.modalForm.title = '新增'
    }
  }
}
</script>
<style>
</style>
